############
 Fluent API
############

The fluent API of the `earthkit-workflows-anemoi` package provides a
convenient way to create and manage workflows for anemoi tasks. It
defines high level functions to begin inference from a variety of
initial conditions, and ways to make anemoi-datasets in a parallel
manner.

.. automodule:: earthkit.workflows.plugins.anemoi.fluent
   :members:
   :no-undoc-members:
   :show-inheritance:
